var restMessageFormatter_1 = require("../dispatcher/restMessageFormatter");
var restFaultFormatter_1 = require("../dispatcher/restFaultFormatter");
var restOperationSelector_1 = require("../dispatcher/restOperationSelector");
var baseAddressMessageFilter_1 = require("../dispatcher/baseAddressMessageFilter");
/**
 * Endpoint behavior that enables REST communication on an endpoint.
 *
 * <uml>
 *  hide members
 *  hide circle
 *  EndpointBehavior <|.. RestBehavior
 * </uml>
 */
var RestBehavior = (function () {
    function RestBehavior() {
    }
    RestBehavior.prototype.applyEndpointBehavior = function (description, endpoint) {
        endpoint.faultFormatter = new restFaultFormatter_1.RestFaultFormatter();
        endpoint.filter = new baseAddressMessageFilter_1.BaseAddressMessageFilter(endpoint.address).and(endpoint.filter);
        endpoint.operationSelector = new restOperationSelector_1.RestOperationSelector(description, endpoint);
        // Note that we assume the operations in the dispatcher line up with the operations in the description. This is
        // true if the dispatcher is created through the DispatcherFactory but could be incorrect otherwise. We'll at
        // least check that the names are the same.
        var operations = description.contract.operations;
        if (operations.length != endpoint.operations.length) {
            throw new Error("DispatchEndpoint and EndpointDescripition do not have the same number of operations.");
        }
        for (var i = 0; i < operations.length; i++) {
            if (endpoint.operations[i].name != operations[i].name) {
                throw new Error("Mismatch between operations in DispatchEndpoint and EndpointDescription");
            }
            endpoint.operations[i].formatter = new restMessageFormatter_1.RestMessageFormatter(endpoint, operations[i]);
        }
    };
    return RestBehavior;
})();
exports.RestBehavior = RestBehavior;
