var rpcFaultFormatter_1 = require("../dispatcher/rpcFaultFormatter");
var rpcMessageFormatter_1 = require("../dispatcher/rpcMessageFormatter");
var rpcOperationSelector_1 = require("../dispatcher/rpcOperationSelector");
var addressMessageFilter_1 = require("../dispatcher/addressMessageFilter");
/**
 * Endpoint behavior that enables RPC communication on an endpoint.
 *
 * <uml>
 *  hide members
 *  hide circle
 *  EndpointBehavior <|.. RpcBehavior
 * </uml>
 */
var RpcBehavior = (function () {
    function RpcBehavior() {
    }
    RpcBehavior.prototype.applyEndpointBehavior = function (description, endpoint) {
        endpoint.faultFormatter = new rpcFaultFormatter_1.RpcFaultFormatter();
        endpoint.operationSelector = new rpcOperationSelector_1.RpcOperationSelector(endpoint);
        endpoint.filter = new addressMessageFilter_1.AddressMessageFilter(endpoint.address).and(endpoint.filter);
        // Note that we assume the operations in the dispatcher line up with the operations in the description. This is
        // true if the dispatcher is created through the DispatcherFactory but could be incorrect otherwise. We'll at
        // least check that the names are the same.
        var operations = description.contract.operations;
        if (operations.length != endpoint.operations.length) {
            throw new Error("DispatchEndpoint and EndpointDescripition do not have the same number of operations.");
        }
        for (var i = 0; i < operations.length; i++) {
            if (endpoint.operations[i].name != operations[i].name) {
                throw new Error("Mismatch between operations in DispatchEndpoint and EndpointDescription");
            }
            endpoint.operations[i].formatter = new rpcMessageFormatter_1.RpcMessageFormatter(operations[i]);
        }
    };
    return RpcBehavior;
})();
exports.RpcBehavior = RpcBehavior;
