import { ServiceDescription, ServiceBehavior } from "../description/serviceDescription";
import { DispatchService } from "../dispatcher/dispatchService";
/**
 * Service behavior that allows for configuration of service options.
 *
 * <uml>
 *  hide members
 *  hide circle
 *  ServiceBehavior <|.. ServiceBehaviorAnnotation
 * </uml>
 */
export declare class ServiceBehaviorAnnotation implements ServiceBehavior {
    /**
     * The name of the service.
     */
    name: string;
    /**
     * Specifies whether to create an OperationContext for operations in this service. The default value is 'false'.
     */
    createOperationContext: boolean;
    constructor(options: ServiceOptions);
    applyServiceBehavior(description: ServiceDescription, service: DispatchService): void;
}
/**
 * Options for a service.
 */
export interface ServiceOptions {
    /**
     * The name of the service.
     */
    name?: string;
    /**
     * Specifies whether to create an OperationContext for operations in this service. The default value is 'false'.
     */
    createOperationContext?: boolean;
}
