/**
 * Service behavior that allows for configuration of service options.
 *
 * <uml>
 *  hide members
 *  hide circle
 *  ServiceBehavior <|.. ServiceBehaviorAnnotation
 * </uml>
 */
var ServiceBehaviorAnnotation = (function () {
    function ServiceBehaviorAnnotation(options) {
        if (!options) {
            throw new Error("Missing required argument 'options'.");
        }
        this.name = options.name;
        this.createOperationContext = options.createOperationContext;
    }
    ServiceBehaviorAnnotation.prototype.applyServiceBehavior = function (description, service) {
        if (this.name != null) {
            service.name = this.name;
        }
        if (this.createOperationContext != null) {
            service.createOperationContext = this.createOperationContext;
        }
    };
    return ServiceBehaviorAnnotation;
})();
exports.ServiceBehaviorAnnotation = ServiceBehaviorAnnotation;
