/**
 * Represents a collection of headers for a [[Message]].
 */
export declare class MessageHeaders {
    /**
     * Object map used to hold headers.
     * @hidden
     */
    private _headers;
    /**
     * Constructs a MessagesHeaders object.
     * @param headers Object map of headers. *Header keys must be lowercase.*
     */
    constructor(headers?: {
        [name: string]: string;
    });
    /**
     * Gets a header.
     * @param name The case insensitive name of the header.
     */
    get(name: string): string;
    /**
     * Sets a header.
     * @param name The case insensitive name of the header.
     * @param value The value of the header.
     */
    set(name: string, value: string): void;
    /**
     * Returns true if the collection contains the header; otherwise, returns false.
     * @param name The case insensitive name of the header.
     */
    has(name: string): boolean;
    /**
     * Deletes a header.
     * @param name The case insensitive name of the header.
     */
    delete(name: string): void;
    /**
     * Merges in the messages headers, overwriting any existing headers.
     * @param headers The headers to merge
     */
    merge(headers: MessageHeaders): void;
    /**
     * Returns the headers as an object map. Will return `undefined` if no headers have been set.
     */
    toObject(): Object;
}
